## Run just once
install.packages("remotes")
remotes::install_github("allisonhorst/palmerpenguins")

library(tidyverse)
library(palmerpenguins)

View(penguins)

# Take care of missing values
penguins.clean <- penguins %>% drop_na()

# See, how many observations are for each species
peng.counts <- penguins.clean %>% 
  group_by(species) %>%
  summarise(count = n())

# And plot the results
ggplot(data = peng.counts, aes(x = species, y=count, fill=species)) +
  geom_col() +
  theme_minimal()

# Try following:
#   - remove "fill=species"
#   - replace "fill=species" with "col=species"
#   - explore documentation of theme_minimal() to find other themes. Apply them.
#       - remove theme_minimal()

# Task 1
# Let's try a different graph (you can pipe data directly to the plotting function)
penguins.clean %>% 
  ggplot(aes(x = ___ , y= ___, col=___)) +
  geom_point() +
  theme_minimal() 

penguins.clean %>% 
  ggplot(aes(x = ___, y=___, ____)) +
  geom_point() +
  theme_minimal() 

# What happens if you replace geom_point() with geom_col()? What does it say?

# Task 2
# Let's see, how penguins in each island differ
penguins.clean %>% 
  ggplot(aes(x = flipper_length_mm, y=body_mass_g, col=island)) +
  geom_point() +
  theme_minimal()

# To differentiate the meaning of color (species vs. island), try different palette
# You can get inspired at https://www.r-graph-gallery.com/38-rcolorbrewers-palettes
# Which palette(s) you think suits best?
install.packages("RColorBrewer")
library(RColorBrewer)

penguins.clean %>% 
  ggplot(aes(x = flipper_length_mm, y=body_mass_g, col=island)) +
  geom_point() +
  theme____() +
  scale_color_brewer(palette = "???")

# Task 3
penguins.clean %>% 
  ggplot(aes(x = flipper_length_mm, y=body_mass_g)) +
  geom_point(aes(shape=___,
                 ___=___)) +
  theme_minimal() +
  scale_color_brewer(palette = "???")

# --------------------------- STATISTICAL ANALYSIS PART ----------------------------
browseURL("https://i.ytimg.com/vi/jSaMm1lK_j8/maxresdefault.jpg")

# Compute the average weight for each species
summary.table <- penguins.clean %>% 
  select(species, body_mass_g) %>%
  group_by(species) %>%
  summarise(mean_weight = mean(body_mass_g))

# But the mean is by itself useless. Why?
# Add standard deviation, which is a measure of how spread the values are
summary.table <- penguins.clean %>% 
  select(species, body_mass_g) %>%
  group_by(species) %>%
  summarise(mean_weight_g = mean(body_mass_g),
            sd_weight_g = sd(body_mass_g))

# Are the differences in SD big or small? Let's visualise
penguins.clean %>% 
  filter(species %in% c('Adelie', 'Chinstrap')) %>% 
  ggplot(aes(x=species, y=body_mass_g, col=species)) +
  geom_point() + coord_flip() +
  theme_minimal()

# Task 1
# Compute standard deviation for Adelie species by hand - use functions mean(), nrow()
# Use the provided vector and check with the reference value
adelie.df <- penguins.clean %>% 
  filter(species == 'Adelie')
# Reference value (uncomment)
#sd(adelie.df$body_mass_g) 
adelie.var <- sum((___ - ___)^2) / (___ - 1)
adelie.sd <- sqrt(adelie.var)

# Better way to visualize the spread of values - histogram
penguins.clean %>% 
  filter(species %in% c('Adelie', 'Chinstrap')) %>% 
  ggplot(aes(x=body_mass_g, fill=species)) +
  geom_histogram() +
  theme_minimal()

# What does a normalized version resemble?
penguins.clean %>% 
  filter(species %in% c('Adelie', 'Chinstrap')) %>% 
  ggplot(aes(x=body_mass_g, col=species)) +
  geom_density(aes(y=..density..)) + xlim(2000, 5000) +
  theme_minimal()

# --------------
# Draw graphs for each species
for(i in 1:nrow(summary.table)) {
  peng.mean <- summary.table$mean_weight_g[i]
  peng.sd <- summary.table$sd_weight_g[i]
  peng <- summary.table$species[i]
  
  peng.plot <- penguins.clean %>% 
    filter(species == peng) %>% 
    ggplot(aes(x=body_mass_g, fill=species)) +
    geom_density(aes(y=..density..)) + xlim(2000, 7000) +
    # Draw mean and SD
    geom_vline(xintercept=peng.mean, size=1) +
    geom_vline(xintercept=peng.mean - 2*peng.sd) +
    geom_vline(xintercept=peng.mean + 2*peng.sd) +
    theme_minimal()
  print(peng.plot)
}


